%define major   3
%define libname %mklibname %{name} %{major}
%define devname %mklibname %{name} -d

Name:           bluez
Summary:        Official Linux Bluetooth protocol stack
Version:        5.50
Release:        %mkrel 1
License:        GPLv2+
Group:          Communications
URL:            http://bluez.org/
Source0:        http://www.kernel.org/pub/linux/bluetooth/%{name}-%{version}.tar.xz
Patch1: 0001-work-around-Logitech-diNovo-Edge-keyboard-firmware-i.patch
Patch2: 0001-Allow-using-obexd-without-systemd-in-the-user-sessio.patch
Patch3: 0001-obex-Use-GLib-helper-function-to-manipulate-paths.patch
Patch5: 0004-agent-Assert-possible-infinite-loop.patch
Obsoletes: bluez-daemon
Requires: bluez-firmware

%description
These are the official Bluetooth communication libraries for Linux.

%post
#migrate old configuration
if [ "$1" = "2" -a -d %{_var}/lib/lib/bluetooth ]; then
 mv -f %{_var}/lib/lib/bluetooth/* %{_var}/lib/bluetooth/ > /dev/null 2>&1 || exit 0
 rmdir %{_var}/lib/lib/bluetooth/ > /dev/null 2>&1 || exit 0
 rmdir %{_var}/lib/lib/ > /dev/null 2>&1 || exit 0
fi

isInFile=$(cat /etc/rc.d/rc.local | grep -c "bluetoothd")
if [ $isInFile -eq 0 ]; then
echo -e '\n/usr/bin/bluetoothd &\n'  >> /etc/rc.d/rc.local 
fi

#remove old symlinks
rm -f /etc/rc.d/rc*.d/*50bluez5


# Ensure that the old broken dangling link will be removed from users system (mga#17682)
# NOTE can be removed for mga7
update-alternatives --remove bluepin /usr/bin/bluepin || :

%preun
#%_preun_service bluetooth

%files
%config %{_sysconfdir}/dbus-1/system.d/bluetooth.conf
%config %{_sysconfdir}/bluetooth/*.conf
%config %{_sysconfdir}/bluetooth/pin
%{_bindir}/bluetoothd
%{_bindir}/obexd
%{_bindir}/btattach
%{_bindir}/ciptool
%{_bindir}/hcitool
%{_bindir}/l2ping
%{_bindir}/rfcomm
%{_bindir}/sdptool
%{_bindir}/bccmd
%{_bindir}/bluetoothctl
%{_bindir}/bluemoon
%{_bindir}/btmon
%{_bindir}/hciattach
%{_bindir}/hciconfig
%{_bindir}/hcidump
%{_bindir}/hex2hcd
%{_bindir}/l2test
%{_bindir}/mpris-proxy
%{_bindir}/rctest
%{_mandir}/man1/btattach.1.*
%{_mandir}/man1/ciptool.1.*
%{_mandir}/man1/hcitool.1.*
%{_mandir}/man1/rfcomm.1.*
%{_mandir}/man1/sdptool.1.*
%{_mandir}/man1/bccmd.1.*
%{_mandir}/man1/hciattach.1.*
%{_mandir}/man1/hciconfig.1.*
%{_mandir}/man1/hcidump.1.*
%{_mandir}/man1/l2ping.1.*
%{_mandir}/man1/rctest.1.*
%{_mandir}/man8/*
%{_libexecdir}/bluetooth/bluetoothd
%{_libexecdir}/bluetooth/obexd
%{_libdir}/bluetooth
%{_localstatedir}/lib/bluetooth
%{_datadir}/dbus-1/system-services/org.bluez.service
%{_datadir}/dbus-1/services/org.bluez.obex.service

#--------------------------------------------------------------------

%package        cups
Summary:        CUPS printer backend for Bluetooth printers
Group:          System/Printing
BuildRequires:  cups-devel

%description    cups
This package contains the CUPS backend for Bluetooth printers.

%files cups
%{_prefix}/lib/cups/backend/bluetooth

#--------------------------------------------------------------------

%package hid2hci
Summary: Put HID proxying bluetooth HCI's into HCI mode
Group: Communications

%description hid2hci
Most allinone PC's and bluetooth keyboard / mouse sets which include a
bluetooth dongle, ship with a so called HID proxying bluetooth HCI.
The HID proxying makes the keyboard / mouse show up as regular USB HID
devices (after connecting using the connect button on the device + keyboard),
which makes them work without requiring any manual configuration.

The bluez-hid2hci package contains the hid2hci utility and udev rules to
automatically switch supported Bluetooth devices into regular HCI mode.

Install this package if you want to use the bluetooth function of the HCI
with other bluetooth devices like for example a mobile phone.

Note that after installing this package you will first need to pair your
bluetooth keyboard and mouse with the bluetooth adapter before you can use
them again. Since you cannot use your bluetooth keyboard and mouse until
they are paired, this will require the use of a regular (wired) USB keyboard
and mouse.

%files hid2hci
/lib/udev/hid2hci
%{_mandir}/man1/hid2hci.1*
/lib/udev/rules.d/97-hid2hci.rules

%post hid2hci
/sbin/udevadm trigger --subsystem-match=usb

#--------------------------------------------------------------------

%package -n     %{libname}
Summary:        Official Linux Bluetooth protocol stack
Group:          System/Libraries

%description -n %{libname}
These are the official Bluetooth communication libraries for Linux.

%files -n %{libname}
%{_libdir}/lib*.so.%{major}*

#--------------------------------------------------------------------

%package -n     %{devname}
Summary:        Headers for developing programs that will use %{name}
Group:          Development/Libraries
Requires:       %{libname} = %{version}
Provides:       lib%{name}-devel = %{version}-%{release}
Provides:       %{name}-devel = %{version}-%{release}

%description -n %{devname}
This package contains the headers that programmers will need to develop
applications which will use libraries from %{name}.

%files -n %{devname}
%doc AUTHORS ChangeLog README
%{_includedir}/bluetooth
%{_libdir}/*.so
%{_libdir}/pkgconfig/bluez.pc

#--------------------------------------------------------------------

%prep
%setup -q
%apply_patches

%build
autoreconf -fi
%define _localstatedir /var
%configure2_5x \
    --enable-cups \
    --enable-tools \
    --enable-library \
    --enable-sixaxis \
    --enable-deprecated \
    --disable-systemd 

%make_build

%install
rm -rf %buildroot
%make_install

# Remove the cups backend from libdir, and install it in /usr/lib whatever the install
%ifarch x86_64
if test -d %{buildroot}%{_libdir}/cups ; then
    install -D -m0755 %{buildroot}%{_libdir}/cups/backend/bluetooth %{buildroot}/usr/lib/cups/backend/bluetooth
    rm -rf %{buildroot}%{_libdir}/cups
fi
%endif

rm -f %{buildroot}%{_sysconfdir}/udev/*.rules
rm -f %{buildroot}/usr/lib/udev/rules.d/*.rules

install -D -p -m0644 tools/hid2hci.rules %{buildroot}/lib/udev/rules.d/97-hid2hci.rules

#install more config files
install -d -m 755 %{buildroot}%{_sysconfdir}/bluetooth

echo "1234" > %{buildroot}%{_sysconfdir}/bluetooth/pin
chmod 600 %{buildroot}%{_sysconfdir}/bluetooth/pin

install -m 644 profiles/network/network.conf %{buildroot}%{_sysconfdir}/bluetooth/
install -m 644 profiles/input/input.conf %{buildroot}%{_sysconfdir}/bluetooth/

# remove unpackaged files
find %{buildroot} -name '*.la' -delete

install -d -m0755 %{buildroot}/%{_localstatedir}/lib/bluetooth

ln -fs %{_libexecdir}/bluetooth/bluetoothd %{buildroot}/%{_bindir}/bluetoothd
ln -fs %{_libexecdir}/bluetooth/obexd %{buildroot}/%{_bindir}/obexd

install -D -p -m0644 src/org.bluez.service %{buildroot}/%{_datadir}/dbus-1/system-services/org.bluez.service

%changelog
* Wed Oct 03 2018 adrianomorselli <adrianomorselli> 5.50.0-1uplos2018
- update
